@@ -3,20 +3,21 @@ from typing import Callable, Dict, Any
 
 from dataclasses import dataclass
 
-from petisco.cron.infrastructure.apscheduler_cron_executor import (
-    APSchedulerCronExecutor,
-)
 
 from petisco.events.publisher.domain.interface_event_publisher import IEventPublisher
 from petisco.events.service_deployed import ServiceDeployed
 from petisco.events.subscriber.domain.interface_event_subscriber import IEventSubscriber
 from petisco.frameworks.interface_application import IApplication
 from petisco.logger.interface_logger import INFO, ILogger
+from petisco.logger.log_message import LogMessage
+from petisco.logger.not_implemented_logger import NotImplementedLogger
 from petisco.application.config.config import Config
 from petisco.application.singleton import Singleton
-from petisco.logger.not_implemented_logger import NotImplementedLogger
 from petisco.application.interface_repository import IRepository
 from petisco.application.interface_service import IService
+from petisco.tasks.infrastructure.apscheduler_cron_executor import (
+    APSchedulerTaskExecutor,
+)
 
 
 @dataclass
@@ -41,16 +42,11 @@ class Petisco(metaclass=Singleton):
         self.app_version = config.app_version
         self.logger = config.get_logger()
         self.info = {"app_name": self.app_name, "app_version": self.app_version}
-        self.set_persistence()
-        self.set_providers()
-        self.set_events()
+        self._set_persistence()
+        self._set_providers()
+        self._set_events()
+        self.set_tasks()
         self.options = config.options
-        if self.info:
-            self.logger.log(INFO, f"Info: {self.info}")
-
-        if self.options:
-            self.logger.log(INFO, f"Options: {self.options}")
-        self.publish_deploy_event()
 
     @staticmethod
     def get_instance():
@@ -89,13 +85,23 @@ class Petisco(metaclass=Singleton):
             )
             self.event_publisher.publish(event)
 
-    def set_cron(self):
-        config_cron = self.config.config_cron
-        if config_cron.jobs:
-            cron_executor = APSchedulerCronExecutor()
-            cron_executor.start(config_cron)
+    def set_tasks(self):
+        config_tasks = self.config.config_tasks
+        if config_tasks.tasks:
+            self.info["tasks"] = {}
+            for task_name, config_task in config_tasks.tasks.items():
+                self.info["tasks"][task_name] = config_task.to_dict()
+            self.cron_executor = APSchedulerTaskExecutor()
 
-    def set_persistence(self):
+    def _schedule_tasks(self):
+        config_tasks = self.config.config_tasks
+        if config_tasks.tasks:
+            self.cron_executor.start(config_tasks)
+
+    def _unschedule_tasks(self):
+        self.cron_executor.stop()
+
+    def _set_persistence(self):
         self._persistence_models = {}
         config_persistence = self.config.config_persistence
         if config_persistence.config:
@@ -106,7 +112,7 @@ class Petisco(metaclass=Singleton):
             self.persistence_configured = True
             self._persistence_models = config_persistence.get_models()
 
-    def set_providers(self):
+    def _set_providers(self):
         config_providers = self.config.config_providers
         if not config_providers:
             return
@@ -139,7 +145,7 @@ class Petisco(metaclass=Singleton):
 
             self.info["repositories"] = info_repositories
 
-    def set_events(self):
+    def _set_events(self):
         config_events = self.config.config_events
         if not config_events:
             return
@@ -165,16 +171,33 @@ class Petisco(metaclass=Singleton):
                     f"Given event_subscriber ({type(self.event_subscriber)}) must implement info"
                 )
 
-    def start(self):
+    def _log_status(self):
+        if self.info:
+            self.logger.log(INFO, LogMessage(data={"message": {"info": self.info}}))
+
+        if self.options:
+            self.logger.log(
+                INFO, LogMessage(data={"message": {"options": self.options}})
+            )
+
+    def _start(self):
         self.event_subscriber.subscribe_all()
-        self.set_cron()
+        self._schedule_tasks()
+        self._log_status()
+        self.publish_deploy_event()
+
+    def start(self):
+        self._start()
         self.config.get_application().start()
 
     def get_app(self):
-        self.event_subscriber.subscribe_all()
-        self.set_cron()
+        self._start()
         return self.config.get_application().get_app()
 
+    def stop(self):
+        self.event_subscriber.unsubscribe_all()
+        self._unschedule_tasks()
+
     @staticmethod
     def services() -> Dict[str, IService]:
         return Petisco.get_instance().services_provider()
