@@ -1,5 +1,5 @@
 import inspect
-import json
+import traceback
 from typing import Tuple, Dict
 
 from petisco.events.event import Event
@@ -13,8 +13,6 @@ REQUEST_RESPONDED_UNWRAP_ERROR = (
     },
 )
 
-REQUEST_RESPONDED_VERSION = "1.4.0"
-
 
 def is_flask_response(value):
     try:
@@ -29,9 +27,9 @@ def is_flask_response(value):
 
 def get_content(value):
     if is_flask_response(value):
-        return "flask response"
+        return {"message": "flask response"}
     else:
-        return json.dumps(value)
+        return value
 
 
 class RequestResponded(Event):
@@ -51,7 +49,6 @@ class RequestResponded(Event):
         is_success: bool,
         http_response: Tuple[Dict, int],
         elapsed_time: float,
-        event_version: str = REQUEST_RESPONDED_VERSION,
     ):
         self.app_name = app_name
         self.app_version = app_version
@@ -59,13 +56,12 @@ class RequestResponded(Event):
         self.is_success = is_success
         self.elapsed_time = elapsed_time
         self.set_http_response(http_response)
-        self.event_version = event_version
         super().__init__()
 
     def set_http_response(self, http_response):
         try:
             _http_response = {
-                "content": json.dumps(REQUEST_RESPONDED_UNWRAP_ERROR),
+                "content": REQUEST_RESPONDED_UNWRAP_ERROR,
                 "status_code": 500,
             }
             if isinstance(http_response, Tuple):
@@ -75,6 +71,7 @@ class RequestResponded(Event):
                 _http_response["content"] = get_content(http_response)
                 _http_response["status_code"] = http_response.status_code
         except Exception as e:  # noqa E722
+            traceback.print_exc()
             frame_info = inspect.stack()[1]
             raise ImportError(
                 f"Error parsing response on Petisco RequestResponded Event\n"
